wifi
----

WiFi tools that could possibly work on a nice day, if you are lucky.

::

    # pip install wifi
    # wifi --help


.. image:: https://travis-ci.org/rockymeza/wifi.png?branch=master
   :target: https://travis-ci.org/rockymeza/wifi

The documentation for wifi lives at https://wifi.readthedocs.org/en/latest/.
